@@ -11,11 +11,10 @@ from tiddlywebplugins.tiddlyspace.web import determine_space, determine_host
 from tiddlywebplugins.tiddlyspace.space import Space
 
 SPACE_SERVER_SETTINGS = 'ServerSettings'
-SERVER_SETTINGS_KEYS = ['lazy', 'index', 'editor']
+SERVER_SETTINGS_KEYS = ['index', 'editor']
 DEFAULT_SERVER_SETTINGS = {
         'index': None,
         'editor': '/takenote#tiddler/{tiddler}',
-        'lazy': False,
         'extra_query': ''}
 DEFAULT_NEWUSER_APP = 'apps'
 DEFAULT_SPACE_NAME = 'frontpage'
@@ -72,8 +71,6 @@ def update_space_settings(environ, name):
             key = key.rstrip().lstrip()
             value = value.rstrip().lstrip()
             if key in SERVER_SETTINGS_KEYS:
-                if key == 'lazy' and value.lower() == 'true':
-                    value = True
                 environ['tiddlyweb.space_settings'][key] = value
             else:
                 query_strings.append('%s=%s' % (key, value))
